@@ -20,7 +20,7 @@ from sqlalchemy import ForeignKey, Column, Table
 from sqlalchemy.types import Integer, DateTime, String, Float
 from sqlalchemy.orm import  relationship
 
-from geoalchemy2 import Geometry
+# from geoalchemy2 import Geometry
 
 from gsshapy.orm import DeclarativeBase
 from gsshapy.orm.file_base import GsshaPyFileObjectBase
@@ -263,7 +263,7 @@ class PrecipGage(DeclarativeBase):
     description = Column(String) #: STRING
     x = Column(Float, nullable=False) #: FLOAT
     y = Column(Float, nullable=False) #: FLOAT
-    geom = Column(Geometry('POINT')) #: POINT
+#     geom = Column(Geometry('POINT')) #: POINT
     
     # Relationship Properties
     values = relationship('PrecipValue', back_populates='gage') #: RELATIONSHIP
@@ -276,7 +276,7 @@ class PrecipGage(DeclarativeBase):
         self.description = description
         self.x = x
         self.y = y
-        self.geom = 'POINT(%s %s)' % (x, y)
+#         self.geom = 'POINT(%s %s)' % (x, y)
         
 
     def __repr__(self):
